@@ -684,7 +684,16 @@ var app = window.Yancy = new Vue({
 
         fillUrl: function ( tmpl, data ) {
             return tmpl.replace( /\{([^}]+)\}/g, function ( match, field ) {
-                return data[field];
+                // This works the same as Mojo::Util xml_escape
+                return data[field].replace( /[&<>"']/g, function ( match ) {
+                    switch ( match ) {
+                        case '&': return '&amp;';
+                        case '<': return '&lt;';
+                        case '>': return '&gt;';
+                        case '"': return '&quot;';
+                        case "'": return '&#039;';
+                    }
+                } );
             } );
         },
 
